==> qip-catalog-library-0.1.1-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/chain/ChainLabel.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.chain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractLabel;

import lombok.*;
import lombok.experimental.SuperBuilder;
import lombok.extern.slf4j.Slf4j;

import jakarta.persistence.*;

import java.util.Objects;

@Getter
@Setter
@Slf4j
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@Entity(name = "chain_labels")
public class ChainLabel extends AbstractLabel {

    @JsonIgnore
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "chain_id")
    private Chain chain;

    public ChainLabel(final String name, final Chain chain) {
        this(name, chain, false);
    }

    public ChainLabel(final String name, final Chain chain, final boolean technical) {
        super(name, technical);
        this.chain = chain;
    }


    @Override
    public boolean equals(Object o) {
        if (!super.equals(o)) {
            return false;
        }

        ChainLabel that = (ChainLabel) o;
        return Objects.equals(chain == null ? null : chain.getId(), that.chain == null ? null : that.chain.getId());
    }

    @Override
    public int hashCode() {
        return super.hashCode() + Objects.hash(chain == null ? null : chain.getId());
    }
}

==> qip-catalog-library-0.1.7-sources.jar: org/qubership/integration/platform/catalog/persistence/configs/entity/chain/ChainLabel.java <==
/*
 * Copyright 2024-2025 NetCracker Technology Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.qubership.integration.platform.catalog.persistence.configs.entity.chain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.SuperBuilder;
import lombok.extern.slf4j.Slf4j;
import org.qubership.integration.platform.catalog.persistence.configs.entity.AbstractLabel;

import java.util.Objects;

@Getter
@Setter
@Slf4j
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@Entity(name = "chain_labels")
public class ChainLabel extends AbstractLabel {

    @JsonIgnore
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "chain_id")
    private Chain chain;

    public ChainLabel(final String name, final Chain chain) {
        this(name, chain, false);
    }

    public ChainLabel(final String name, final Chain chain, final boolean technical) {
        super(name, technical);
        this.chain = chain;
    }


    @Override
    public boolean equals(Object o) {
        if (!super.equals(o)) {
            return false;
        }

        ChainLabel that = (ChainLabel) o;
        return Objects.equals(chain == null ? null : chain.getId(), that.chain == null ? null : that.chain.getId());
    }

    @Override
    public int hashCode() {
        return super.hashCode() + Objects.hash(chain == null ? null : chain.getId());
    }
}
